What is Alabaster? — SxcAPIClient 0.1.0 documentation

# What is Alabaster?

Alabaster is a visually (c)lean, responsive, configurable theme for the Sphinx documentation system. It is Python 2+3 compatible.

It began as a third-party theme, and is still maintained separately, but as of Sphinx 1.3, Alabaster is an install-time dependency of Sphinx and is selected as the default theme.

Live examples of this theme can be seen on this project’s own website, paramiko.org, fabfile.org and pyinvoke.org.

For more documentation, please see http://alabaster.readthedocs.io.

Note

You can install the development version via `pip install -e git+https://github.com/bitprophet/alabaster/#egg=alabaster`.